==> subtitlecomposer-0.4.1.tar.bz2: subtitlecomposer-0.4.1/src/formats/outputformat.h <==
#ifndef OUTPUTFORMAT_H
#define OUTPUTFORMAT_H

/***************************************************************************
 *   Copyright (C) 2007-2008 by Sergio Pistone                             *
 *   sergio_pistone@yahoo.com.ar                                           *
 *                                                                         *
 *   This program is free software; you can redistribute it and/or modify  *
 *   it under the terms of the GNU General Public License as published by  *
 *   the Free Software Foundation; either version 2 of the License, or     *
 *   (at your option) any later version.                                   *
 *                                                                         *
 *   This program is distributed in the hope that it will be useful,       *
 *   but WITHOUT ANY WARRANTY; without even the implied warranty of        *
 *   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the         *
 *   GNU General Public License for more details.                          *
 *                                                                         *
 *   You should have received a copy of the GNU General Public License     *
 *   along with this program; if not, write to the                         *
 *   Free Software Foundation, Inc.,                                       *
 *   59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.             *
 ***************************************************************************/

#ifdef HAVE_CONFIG_H
	#include <config.h>
#endif

#include "format.h"

#include <qstringlist.h>
#include <qfile.h>
#include <qtextcodec.h>

namespace SubtitleComposer
{
	class OutputFormat : public Format
	{
		public:

			~OutputFormat() {}

			bool writeSubtitle( const Subtitle& subtitle, NewLine newLine, bool primary, const QString& path, QTextCodec* codec, bool overwrite ) const
			{
				if ( ! overwrite )
				{
					if ( QFile::exists( path ) )
						return false;
				}

				QFile file( path );
				if ( ! file.open( IO_WriteOnly|IO_Truncate ) )
				{
					kdDebug() << "couldn't open output file " << file.name() << endl;
					return false;
				}

				QString data = dumpSubtitles( subtitle, primary );

				if ( newLine == Windows )
					data.replace( "\n", "\r\n" );
				else if ( newLine == Macintosh )
					data.replace( "\n", "\r" );
	
				QTextStream stream( &file );
				stream.setCodec( codec );
				stream << data;

				file.close();

				return true;
			}

			virtual QString dumpSubtitles( const Subtitle& subtitle, bool secondary ) const = 0;

		protected:

			OutputFormat( const QString& name, const QStringList& extensions ):
				Format( name, extensions ) {}
	};

}

#endif

==> subtitlecomposer-0.4.2.tar.bz2: subtitlecomposer-0.4.2/src/formats/outputformat.h <==
#ifndef OUTPUTFORMAT_H
#define OUTPUTFORMAT_H

/***************************************************************************
 *   Copyright (C) 2007-2008 by Sergio Pistone                             *
 *   sergio_pistone@yahoo.com.ar                                           *
 *                                                                         *
 *   This program is free software; you can redistribute it and/or modify  *
 *   it under the terms of the GNU General Public License as published by  *
 *   the Free Software Foundation; either version 2 of the License, or     *
 *   (at your option) any later version.                                   *
 *                                                                         *
 *   This program is distributed in the hope that it will be useful,       *
 *   but WITHOUT ANY WARRANTY; without even the implied warranty of        *
 *   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the         *
 *   GNU General Public License for more details.                          *
 *                                                                         *
 *   You should have received a copy of the GNU General Public License     *
 *   along with this program; if not, write to the                         *
 *   Free Software Foundation, Inc.,                                       *
 *   59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.             *
 ***************************************************************************/

#ifdef HAVE_CONFIG_H
	#include <config.h>
#endif

#include "format.h"
#include <filesavehelper.h>

#include <qstringlist.h>
#include <qfile.h>
#include <qtextcodec.h>
#include <qtextstream.h>


namespace SubtitleComposer
{
	class OutputFormat : public Format
	{
		public:

			~OutputFormat() {}

			bool writeSubtitle( const Subtitle& subtitle, NewLine newLine, bool primary, const KURL& url, QTextCodec* codec, bool overwrite ) const
			{
				FileSaveHelper fileSaveHelper( url, overwrite );

				if ( ! fileSaveHelper.open() )
					return false;

				QString data = dumpSubtitles( subtitle, primary );
				if ( newLine == Windows )
					data.replace( "\n", "\r\n" );
				else if ( newLine == Macintosh )
					data.replace( "\n", "\r" );

				QTextStream stream( fileSaveHelper.file() );
				stream.setCodec( codec );
				stream << data;

				return fileSaveHelper.close();
			}

			virtual QString dumpSubtitles( const Subtitle& subtitle, bool secondary ) const = 0;

		protected:

			OutputFormat( const QString& name, const QStringList& extensions ):
				Format( name, extensions ) {}
	};

}

#endif
